@@ -18,7 +18,6 @@
  *
  */
 
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Signals = imports.signals;
 
@@ -101,44 +100,42 @@ var State = {
 };
 
 
-var BlurEffect = new Lang.Class({
-    Name: 'PmodoroBlurEffect',
-    Extends: Clutter.ShaderEffect,
-
+var BlurEffect = GObject.registerClass(
+class PomodoroBlurEffect extends Clutter.ShaderEffect {
     _init(params) {
         params = Params.parse(params, { orientation: Clutter.Orientation.HORIZONTAL,
                                         brightness: 1.0,
                                         factor: 1.0 });
 
-        this.parent({ shader_type: Clutter.ShaderType.FRAGMENT_SHADER });
+        super._init({ shader_type: Clutter.ShaderType.FRAGMENT_SHADER });
 
         this.orientation = params.orientation;
         this.brightness = params.brightness;
         this.factor = params.factor;
 
         this.set_shader_source(BLUR_FRAGMENT_SHADER);
-    },
+    }
 
     get brightness() {
         return this._brightness;
-    },
+    }
 
     set brightness(value) {
         this.set_uniform_value('brightness', GObject.Float(value));
         this._brightness = value;
-    },
+    }
 
     get factor() {
         return this._factor;
-    },
+    }
 
     set factor(value) {
         this.set_uniform_value('factor', GObject.Float(value));
         this._factor = value;
-    },
+    }
 
     vfunc_pre_paint() {
-        let res = this.parent();
+        let res = super.vfunc_pre_paint();
         let [success, width, height] = this.get_target_size();
 
         if (success) {
@@ -148,7 +145,7 @@ var BlurEffect = new Lang.Class({
                 this.set_uniform_value('y_step', GObject.Float(1.0 / height));
             }
             else {
-                this.set_uniform_value('x_step', - GObject.Float(1.0 / width));
+                this.set_uniform_value('x_step', GObject.Float(-1.0 / width));
                 this.set_uniform_value('y_step', GObject.Float(1.0 / height));
             }
         }
@@ -163,7 +160,6 @@ var BlurEffect = new Lang.Class({
 
 
 var BlurredLightbox = class extends Lightbox.Lightbox {
-
     constructor(container, params) {
         params.radialEffect = false;
 
@@ -178,9 +174,12 @@ var BlurredLightbox = class extends Lightbox.Lightbox {
                                                  brightness: this._fadeFactor,
                                                  factor: 0.0 });
 
+            this._blurXEffect.set_enabled(false);
+            this._blurYEffect.set_enabled(false);
+
             // Clone the group that contains all of UI on the screen.  This is the
             // chrome, the windows, etc.
-            let uiGroupClone = new Clutter.Clone({ source: Main.layoutManager.uiGroup,
+            let uiGroupClone = new Clutter.Clone({ source: Main.uiGroup,
                                                    clip_to_allocation: true });
             uiGroupClone.add_effect(this._blurXEffect);
             uiGroupClone.add_effect(this._blurYEffect);
@@ -209,6 +208,8 @@ var BlurredLightbox = class extends Lightbox.Lightbox {
                                    this.emit('shown');
                                }
                              });
+            this._blurXEffect.set_enabled(true);
+            this._blurYEffect.set_enabled(true);
         } else {
             Tweener.removeTweens(this.actor);
             Tweener.addTween(this.actor,
@@ -240,6 +241,9 @@ var BlurredLightbox = class extends Lightbox.Lightbox {
                                    this._blurYEffect.factor = this._blurXEffect.factor;
                                },
                                onComplete: () => {
+                                   this._blurXEffect.set_enabled(false);
+                                   this._blurYEffect.set_enabled(false);
+
                                    this.actor.hide();
                                }
                              });
@@ -263,10 +267,8 @@ var BlurredLightbox = class extends Lightbox.Lightbox {
  * class to have more event signals, different fade in/out times, and different
  * event blocking behavior.
  */
-var ModalDialog = new Lang.Class({
-    Name: 'PomodoroModalDialog',
-
-    _init() {
+var ModalDialog = class {
+    constructor() {
         this.state = State.CLOSED;
 
         this._idleMonitor          = Meta.IdleMonitor.get_core();
@@ -308,11 +310,11 @@ var ModalDialog = new Lang.Class({
 
         global.stage.add_actor(this.actor);
         global.focus_manager.add_group(this.actor);
-    },
+    }
 
     get isOpened() {
         return this.state == State.OPENED || this.state == State.OPENING;
-    },
+    }
 
     _addMessageTray() {
         let messageTray = Main.messageTray;
@@ -325,7 +327,7 @@ var ModalDialog = new Lang.Class({
 
         messageTray.actor.unref();
         messageTray.bannerBlocked = false;
-    },
+    }
 
     _removeMessageTray() {
         let messageTray = Main.messageTray;
@@ -337,7 +339,7 @@ var ModalDialog = new Lang.Class({
         Main.layoutManager.addChrome(messageTray.actor, { affectsInputRegion: false });
 
         messageTray.actor.unref();
-    },
+    }
 
     open(animate) {
         if (this.state == State.OPENED || this.state == State.OPENING) {
@@ -387,7 +389,7 @@ var ModalDialog = new Lang.Class({
             this.emit('opening');
             this.emit('opened');
         }
-    },
+    }
 
     close(animate) {
         this._cancelOpenWhenIdle();
@@ -432,7 +434,7 @@ var ModalDialog = new Lang.Class({
             this.emit('closing');
             this.emit('closed');
         }
-    },
+    }
 
     _onPushModalDelayTimeout() {
         /* Don't become modal and block events just yet,
@@ -451,7 +453,7 @@ var ModalDialog = new Lang.Class({
 
         this._pushModalDelaySource = 0;
         return GLib.SOURCE_REMOVE;
-    },
+    }
 
     _pushModal() {
         if (this.state == State.CLOSED || this.state == State.CLOSING) {
@@ -463,7 +465,7 @@ var ModalDialog = new Lang.Class({
             focus: this._lightbox.actor,
             onUngrab: this._onUngrab.bind(this)
         });
-    },
+    }
 
     _onPushModalTimeout() {
         if (this.state == State.CLOSED || this.state == State.CLOSING) {
@@ -485,7 +487,7 @@ var ModalDialog = new Lang.Class({
         }
 
         return GLib.SOURCE_CONTINUE;
-    },
+    }
 
     pushModal() {
         if (this.state == State.CLOSED || this.state == State.CLOSING) {
@@ -513,7 +515,7 @@ var ModalDialog = new Lang.Class({
 
                 return GLib.SOURCE_REMOVE;
             });
-    },
+    }
 
     /**
      * Drop modal status without closing the dialog; this makes the
@@ -534,7 +536,7 @@ var ModalDialog = new Lang.Class({
         }
 
         this._disconnectSignals();
-    },
+    }
 
     _disconnectSignals() {
         if (this._pushModalDelaySource) {
@@ -551,11 +553,11 @@ var ModalDialog = new Lang.Class({
             this._idleMonitor.remove_watch(this._pushModalWatchId);
             this._pushModalWatchId = 0;
         }
-    },
+    }
 
     _onUngrab() {
         this.close(true);
-    },
+    }
 
     _onActorDestroy() {
         if (this._destroyed)
@@ -567,21 +569,18 @@ var ModalDialog = new Lang.Class({
         this.actor._delegate = null;
 
         this.emit('destroy');
-    },
+    }
 
     destroy() {
         this.actor.destroy();
     }
-});
+};
 Signals.addSignalMethods(ModalDialog.prototype);
 
 
-var PomodoroEndDialog = new Lang.Class({
-    Name: 'PomodoroEndDialog',
-    Extends: ModalDialog,
-
-    _init(timer) {
-        this.parent();
+var PomodoroEndDialog = class extends ModalDialog {
+    constructor(timer) {
+        super();
 
         this.timer = timer;
         this.description = _("It's time to take a break");
@@ -592,8 +591,16 @@ var PomodoroEndDialog = new Lang.Class({
         this._actorMappedId              = 0;
         this._timerUpdateId              = 0;
         this._eventId                    = 0;
+        this._styleChangedId             = 0;
 
-        this._timerLabel = new St.Label({ style_class: 'extension-pomodoro-dialog-timer' });
+        this._minutesLabel = new St.Label();
+        this._separatorLabel = new St.Label({ text: ":" });
+        this._secondsLabel = new St.Label();
+
+        let hbox = new St.BoxLayout({ vertical: false, style_class: 'extension-pomodoro-dialog-timer' });
+        hbox.add(this._minutesLabel);
+        hbox.add(this._separatorLabel);
+        hbox.add(this._secondsLabel);
 
         this._descriptionLabel = new St.Label({
                                        style_class: 'extension-pomodoro-dialog-description',
@@ -603,22 +610,26 @@ var PomodoroEndDialog = new Lang.Class({
 
         let box = new St.BoxLayout({ style_class: 'extension-pomodoro-dialog-box',
                                      vertical: true });
-        box.add(this._timerLabel,
-                { y_fill: false,
-                  y_align: St.Align.START });
+        box.add(hbox,
+                { x_fill: false,
+                  x_align: St.Align.MIDDLE });
         box.add(this._descriptionLabel,
-                { y_fill: false,
-                  y_align: St.Align.START });
+                { x_fill: false,
+                  x_align: St.Align.MIDDLE });
         this._layout.add_actor(box);
 
         this._actorMappedId = this.actor.connect('notify::mapped', this._onActorMappedChanged.bind(this));
 
         this.connect('closing', this._onClosing.bind(this));
         this.connect('destroy', this._onDestroy.bind(this));
-    },
+    }
 
     _onActorMappedChanged(actor) {
         if (actor.mapped) {
+            if (!this._styleChangedId) {
+                this._styleChangedId = this._secondsLabel.connect('style-changed', this._onStyleChanged.bind(this));
+                this._onStyleChanged(this._secondsLabel);
+            }
             if (!this._timerUpdateId) {
                 this._timerUpdateId = this.timer.connect('update', this._onTimerUpdate.bind(this));
                 this._onTimerUpdate();
@@ -630,7 +641,17 @@ var PomodoroEndDialog = new Lang.Class({
                 this._timerUpdateId = 0;
             }
         }
-    },
+    }
+
+    _onStyleChanged(actor) {
+        let themeNode = actor.get_theme_node();
+        let font      = themeNode.get_font();
+        let context   = actor.get_pango_context();
+        let metrics   = context.get_metrics(font, context.get_language());
+        let digitWidth = metrics.get_approximate_digit_width() / Pango.SCALE;
+
+        this._secondsLabel.natural_width = 2 * digitWidth;
+    }
 
     _onTimerUpdate() {
         if (this.timer.isBreak()) {
@@ -639,11 +660,14 @@ var PomodoroEndDialog = new Lang.Class({
             let seconds   = Math.floor(remaining % 60);
 
             /* method may be called while label actor got destroyed */
-            if (this._timerLabel.clutter_text) {
-                this._timerLabel.clutter_text.set_text('%02d:%02d'.format(minutes, seconds));
+            if (this._minutesLabel.clutter_text) {
+                this._minutesLabel.clutter_text.set_text('%d'.format(minutes));
+            }
+            if (this._secondsLabel.clutter_text) {
+                this._secondsLabel.clutter_text.set_text('%02d'.format(seconds));
             }
         }
-    },
+    }
 
     _onClosing() {
         this._cancelCloseWhenActive();
@@ -663,7 +687,12 @@ var PomodoroEndDialog = new Lang.Class({
             this.timer.disconnect(this._timerUpdateId);
             this._timerUpdateId = 0;
         }
-    },
+
+        if (this._styleChangedId) {
+            this._secondsLabel.disconnect(this._styleChangedId);
+            this._styleChangedId = 0;
+        }
+    }
 
     _onDestroy() {
         this._onClosing();
@@ -672,7 +701,7 @@ var PomodoroEndDialog = new Lang.Class({
             this.actor.disconnect(this._actorMappedId);
             this._actorMappedId = 0;
         }
-    },
+    }
 
     _onEvent(actor, event) {
         let x, y, dx, dy, distance;
@@ -728,13 +757,13 @@ var PomodoroEndDialog = new Lang.Class({
         }
 
         return Clutter.EVENT_STOP;
-    },
+    }
 
     /**
      * Open the dialog and setup closing when user becomes active.
      */
     open(animate) {
-        this.parent(animate);
+        super.open(animate);
 
         /* Wait until user has a chance of seeing the dialog */
         if (this._closeWhenActiveDelaySource == 0) {
@@ -754,14 +783,14 @@ var PomodoroEndDialog = new Lang.Class({
                     return GLib.SOURCE_REMOVE;
                 });
         }
-    },
+    }
 
     _cancelOpenWhenIdle() {
         if (this._openWhenIdleWatchId) {
             this._idleMonitor.remove_watch(this._openWhenIdleWatchId);
             this._openWhenIdleWatchId = 0;
         }
-    },
+    }
 
     openWhenIdle() {
         if (this.state == State.OPEN || this.state == State.OPENING) {
@@ -788,14 +817,14 @@ var PomodoroEndDialog = new Lang.Class({
                     this.open(true);
                 });
         }
-    },
+    }
 
     _cancelCloseWhenActive() {
         if (this._eventId) {
             this._lightbox.actor.disconnect(this._eventId);
             this._eventId = 0;
         }
-    },
+    }
 
     // TODO: should be private
     closeWhenActive() {
@@ -808,7 +837,7 @@ var PomodoroEndDialog = new Lang.Class({
             this._eventY = -1;
             this._eventId = this._lightbox.actor.connect('event', this._onEvent.bind(this));
         }
-    },
+    }
 
     setDescription(text) {
         this.description = text;
@@ -817,4 +846,4 @@ var PomodoroEndDialog = new Lang.Class({
             this._descriptionLabel.clutter_text.set_text(this.description);
         }
     }
-});
+};
