@@ -18,7 +18,6 @@
  *          Kamil Prusko <kamilprusko@gmail.com>
  */
 
-const Lang = imports.lang;
 const Mainloop = imports.mainloop;
 const Cairo = imports.cairo;
 const Signals = imports.signals;
@@ -64,9 +63,8 @@ var IndicatorType = {
 
 
 var IndicatorMenu = class extends PopupMenu.PopupMenu {
-
     constructor(indicator) {
-        super(indicator.actor, St.Align.START, St.Side.TOP);
+        super(indicator, St.Align.START, St.Side.TOP);
 
         this._isPaused = null;
         this._timerState = null;
@@ -296,18 +294,16 @@ var IndicatorMenu = class extends PopupMenu.PopupMenu {
         }
 
         this.indicator = null;
+        this.timerLabel = null;
+        this.pauseAction = null;
 
         super.destroy();
     }
 };
 
 
-var TextIndicator = GObject.registerClass(
-class PomodoroTextIndicator extends GObject.Object {
-
-    _init(timer) {
-        super._init();
-
+var TextIndicator = class {
+    constructor(timer) {
         this._initialized     = false;
         this._state           = Timer.State.NULL;
         this._minHPadding     = 0;
@@ -369,7 +365,6 @@ class PomodoroTextIndicator extends GObject.Object {
         return Math.ceil(4 * this._digitWidth + 0.5 * this._charWidth);
     }
 
-
     _getText(state, remaining) {
         if (remaining < 0.0) {
             remaining = 0.0;
@@ -405,7 +400,6 @@ class PomodoroTextIndicator extends GObject.Object {
         this.label.set_text(this._getText(state, remaining));
     }
 
-
     _onActorDestroy() {
         if (this._onTimerUpdateId) {
             this.timer.disconnect(this._onTimerUpdateId);
@@ -420,15 +414,13 @@ class PomodoroTextIndicator extends GObject.Object {
     destroy() {
         this.actor.destroy();
     }
-});
+};
 Signals.addSignalMethods(TextIndicator.prototype);
 
 
-var ShortTextIndicator = GObject.registerClass(
-class PomodoroShortTextIndicator extends TextIndicator {
-
-    _init(timer) {
-        super._init(timer);
+var ShortTextIndicator = class extends TextIndicator {
+    constructor(timer) {
+        super(timer);
 
         this.label.set_x_align(Clutter.ActorAlign.END);
     }
@@ -454,14 +446,10 @@ class PomodoroShortTextIndicator extends TextIndicator {
                 ? "%d′".format(minutes, remaining)
                 : "%d″".format(seconds, remaining);
     }
-});
-
-var IconIndicator = GObject.registerClass(
-class PomodoroIconIndicator extends GObject.Object {
-
-    _init(timer) {
-        super._init();
+};
 
+var IconIndicator = class {
+    constructor(timer) {
         this._state           = Timer.State.NULL;
         this._progress        = 0.0;
         this._minHPadding     = 0;
@@ -604,21 +592,19 @@ class PomodoroIconIndicator extends GObject.Object {
     destroy() {
         this.actor.destroy();
     }
-});
+};
 Signals.addSignalMethods(IconIndicator.prototype);
 
 
 var Indicator = GObject.registerClass(
 class PomodoroIndicator extends PanelMenu.Button {
-
     _init(timer, type) {
         super._init(St.Align.START, _("Pomodoro"), true);
 
         this.timer  = timer;
         this.widget = null;
 
-        this.actor.add_style_class_name('extension-pomodoro-indicator');
-        this.actor.connect('destroy', this._onActorDestroy.bind(this));
+        this.add_style_class_name('extension-pomodoro-indicator');
 
         this._arrow = PopupMenu.arrowIcon(St.Side.BOTTOM);
         this._blinking = false;
@@ -628,7 +614,7 @@ class PomodoroIndicator extends PanelMenu.Button {
         this._hbox.pack_start = true;
         this._hbox.set_y_align(Clutter.ActorAlign.CENTER);
         this._hbox.add_child(this._arrow);
-        this.actor.add_child(this._hbox);
+        this.add_child(this._hbox);
 
         this.setMenu(new IndicatorMenu(this));
         this.setType(type);
@@ -637,6 +623,24 @@ class PomodoroIndicator extends PanelMenu.Button {
 
         this._timerPausedId = this.timer.connect('paused', this._onTimerPaused.bind(this));
         this._timerResumedId = this.timer.connect('resumed', this._onTimerResumed.bind(this));
+
+        let destroyId = this.connect('destroy', () => {
+            if (this._blinkTimeoutSource != 0) {
+                Mainloop.source_remove(this._blinkTimeoutSource);
+                this._blinkTimeoutSource = 0;
+            }
+
+            this.timer.disconnect(this._timerPausedId);
+            this.timer.disconnect(this._timerResumedId);
+            this.timer = null;
+
+            if (this.icon) {
+                this.icon.destroy();
+                this.icon = null;
+            }
+
+            this.disconnect(destroyId);
+        })
     }
 
     setType(type) {
@@ -748,28 +752,4 @@ class PomodoroIndicator extends PanelMenu.Button {
             }
         }
     }
-
-    _onActorDestroy() {
-        Tweener.removeTweens(this._hbox);
-        Tweener.removeTweens(this.menu.timerLabel);
-        Tweener.removeTweens(this.menu.pauseAction.child);
-
-        if (this._blinkTimeoutSource != 0) {
-            Mainloop.source_remove(this._blinkTimeoutSource);
-            this._blinkTimeoutSource = 0;
-        }
-
-        this.timer.disconnect(this._timerPausedId);
-        this.timer.disconnect(this._timerResumedId);
-        this.timer = null;
-
-        if (this.icon) {
-            this.icon.destroy();
-            this.icon = null;
-        }
-    }
-
-    destroy() {
-        super.destroy();
-    }
 });
